<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://ays-pro.com/
 * @since      1.0.0
 *
 * @package    Ays_Slider
 * @subpackage Ays_Slider/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Ays_Slider
 * @subpackage Ays_Slider/admin
 * @author     Image Slider Team <info@ays-pro.com>
 */
class Ays_Slider_Admin {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;
    private $slider_obj;
    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $plugin_name       The name of this plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct($plugin_name, $version) {

        $this->plugin_name = $plugin_name;
        $this->version = $version;
        add_filter('set-screen-option', array(__CLASS__, 'set_screen'), 10, 3);
    }

    /**
     * Register the stylesheets for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_styles($hook_suffix) {
        wp_enqueue_style($this->plugin_name . '-admin', plugin_dir_url(__FILE__) . 'css/admin.css', array(), $this->version, 'all');

        if (false === strpos($hook_suffix, $this->plugin_name)) {
            return;
        }

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Ays_Slider_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Ays_Slider_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        wp_enqueue_style('wp-color-picker');
        wp_enqueue_style('ays_sld_animate.css', plugin_dir_url(__FILE__) . 'css/animate.min.css', array(), '3.7.0', 'all');
        wp_enqueue_style('ays_sld_font_awesome', plugin_dir_url(__FILE__) . 'css/font_awesome_all.css', array(), '5.6.3', 'all');
        wp_enqueue_style('ays_sld_fa_v4_shims', plugin_dir_url(__FILE__) . 'css/font_awesome_v4-shims.css', array(), '5.6.3', 'all');
        wp_enqueue_style('ays_sld_bootstrap', plugin_dir_url(__FILE__) . 'css/bootstrap.min.css', array(), '4.1.3', 'all');
        wp_enqueue_style('ays_sld_select2', plugin_dir_url(__FILE__) . 'css/select2.min.css', array(), '4.0.5', 'all');
        wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/ays-slider-admin.css', array(), $this->version, 'all');

    }

    /**
     * Register the JavaScript for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts($hook_suffix) {
        // wp_enqueue_script($this->plugin_name . '-adminjs', plugin_dir_url(__FILE__) . 'js/admin.js', array('jquery'), $this->version, true);

        if (false === strpos($hook_suffix, $this->plugin_name)) {
            return;
        }

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Ays_Slider_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Ays_Slider_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        wp_enqueue_script('jquery-effects-core');
        wp_enqueue_script('jquery-ui-sortable');
        wp_enqueue_media();
        wp_enqueue_script('wp-color-picker-alpha', plugin_dir_url(__FILE__) . 'js/wp-color-picker-alpha.min.js', array('wp-color-picker') , '2.1.3' , true);
        wp_enqueue_editor();
        wp_enqueue_script('ays_sld_popper', plugin_dir_url(__FILE__) . 'js/popper.min.js', array('jquery'), '1.14.3', true);
        wp_enqueue_script('ays_sld_bootstrap', plugin_dir_url(__FILE__) . 'js/bootstrap.min.js', array('jquery'), '4.1.3', true);
        wp_enqueue_script('ays_sld_select2', plugin_dir_url(__FILE__) . 'js/select2.min.js', array('jquery'), '4.0.5', true);
        wp_enqueue_script('ays_sld_imagesloaded', plugin_dir_url(__FILE__) . 'js/imagesloaded.pkgd.min.js', array('jquery'), '4.0.0', true);
        wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/ays-slider-admin.js', array('jquery', 'wp-color-picker'), $this->version, true);

    }

    /**
     * Register the administration menu for this plugin into the WordPress Dashboard menu.
     *
     * @since    1.0.0
     */

    public function add_plugin_admin_menu() {
        add_options_page(__('Ays Slider', $this->plugin_name), __('Ays Slider', $this->plugin_name), 'manage_options', $this->plugin_name, array($this, 'display_plugin_setup_page'));
        $hook_slider = add_menu_page(__('Ays Slider', $this->plugin_name), __('Ays Slider', $this->plugin_name), 'manage_options', $this->plugin_name, array($this, 'display_plugin_setup_page'), AYS_SLD_ADMIN_URL . 'images/icon.png', '6.34');
        add_action("load-$hook_slider", [$this, 'screen_option_slider']);
    }

    /**
     * Add settings action link to the plugins page.
     *
     * @since    1.0.0
     */

    public function add_action_links($links) {
        /*
         *  Documentation : https://codex.wordpress.org/Plugin_API/Filter_Reference/plugin_action_links_(plugin_file_name)
         */
        $settings_link = array(
            '<a href="' . admin_url('options-general.php?page=' . $this->plugin_name) . '">' . __('Settings', $this->plugin_name) . '</a>',
        );
        return array_merge($settings_link, $links);

    }

    /**
     * Render the settings page for this plugin.
     *
     * @since    1.0.0
     */

    public function display_plugin_setup_page() {
        $action = (isset($_GET['action'])) ? sanitize_text_field($_GET['action']) : '';

        switch ($action) {
        case 'add':
            include_once 'partials/actions/ays-slider-admin-actions.php';
            break;
        case 'edit':
            include_once 'partials/actions/ays-slider-admin-actions.php';
            break;
        default:
            include_once 'partials/ays-slider-admin-display.php';
        }
    }

    public static function set_screen($status, $option, $value) {
        return $value;
    }

    public function screen_option_slider() {
        $option = 'per_page';
        $args = array(
            'label' => __('Sliders', $this->plugin_name),
            'default' => 5,
            'option' => 'sliders_per_page',
        );

        add_screen_option($option, $args);
        $this->slider_obj = new Ays_Slider_List_Table($this->plugin_name);
    }

    public function register_ays_slider_widget() {
        global $wpdb;

        $sql = "SELECT COUNT(*) FROM {$wpdb->prefix}ays_slider";

        $c = $wpdb->get_var($sql);
        if (0 == $c) {return;} else {
            register_widget('Ays_Slider_Widget');
        }
    }
}