<?php
global $ays_slider_db_version;
$ays_slider_db_version = '2.3.3';
/**
 * Fired during plugin activation
 *
 * @link       https://ays-pro.com/
 * @since      1.0.0
 *
 * @package    Ays_Slider
 * @subpackage Ays_Slider/includes
 */

/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      1.0.0
 * @package    Ays_Slider
 * @subpackage Ays_Slider/includes
 * @author     Image Slider Team <info@ays-pro.com>
 */
class Ays_Slider_Activator {

    /**
     * Short Description. (use period)
     *
     * Long Description.
     *
     * @since    1.0.0
     */
    public static function activate() {
        $installed_ver = get_option("ays_slider_db_version");
        global $ays_slider_db_version;
        if ($installed_ver != $ays_slider_db_version) {

            require_once ABSPATH . 'wp-admin/includes/upgrade.php';
            global $wpdb;

            $table = $wpdb->prefix . 'ays_slider';
            $charset_collate = $wpdb->get_charset_collate();

            $sql = "CREATE TABLE $table (
                      id INT(16) UNSIGNED NOT NULL AUTO_INCREMENT,
                      title VARCHAR(255) NOT NULL,
                      description TEXT NOT NULL,
                      images TEXT NOT NULL,
                      images_titles TEXT NOT NULL,
                      images_descs TEXT NOT NULL,
                      images_alts TEXT NOT NULL,
                      images_urls TEXT NOT NULL,
                      images_dates TEXT NOT NULL,
                      width INT(16) NOT NULL,
                      height INT NOT NULL,
                      options TEXT NOT NULL,
                      custom_css TEXT NOT NULL,
                      PRIMARY KEY (id)
                    )$charset_collate;";
            dbDelta($sql);
            update_option('ays_slider_db_version', $ays_slider_db_version);
        }
    }

    public static function ays_slider_db_check() {
        global $ays_slider_db_version;
        if (get_site_option('ays_slider_db_version') != $ays_slider_db_version) {
            self::activate();
            self::alter_tables();
        }
    }

    public static function alter_tables() {
        global $wpdb;
        $table = $wpdb->prefix . 'ays_slider';
        $old_table = $wpdb->prefix . 'nk_slider_table';
        if ($wpdb->get_var("SHOW TABLES LIKE '$old_table'") == $old_table) {
            $res = $wpdb->get_results("SELECT * FROM " . $old_table, 'ARRAY_A');
            if (!empty($res)) {
                foreach ($res as $result) {
                    $options = array(
                        "admin_pagination" => "all",
                        'show_title' => 1,
                        'images_orderby' => 'noordering',
                        'margin' => 0,
                        'images_loading' => "current_loaded",
                        'nav_arrows' => 1,
                        'nav_dots' => 0,
                        'nav_type' => 'dots',
                        'thumb_w' => $result['thumb_width'],
                        'thumb_h' => $result['thumb_height'],
                        'pause_hover' => 1,
                        'animation_in' => "slideInLeft",
                        'animation_out' => "slideOutRight",
                        'animation_speed' => 650,
                        'border_radius' => 0,
                        'timeout' => $result['slide_duration'] > 0 ? $result['slide_duration'] : 3000,
                        'image_object_fit' => 'contain',
                        'slider_bgcolor' => '#ffffff',
                        'slider_title_color' => '#ffffff'
                    );
                    $result_imgs_count = count(explode('***', rtrim($result['slider_files'], "*")));
                    $result['slider_text'] = '' == $result['slider_text'] ? str_repeat('***', $result_imgs_count - 1) : rtrim($result['slider_text'], "*");
                    $result['slider_urls'] = '' == $result['slider_urls'] ? str_repeat('***', $result_imgs_count - 1) : rtrim($result['slider_urls'], "*");
                    $ts = DateTime::createFromFormat("d/m/Y H:i:s", $result['slider_date'])->getTimestamp();
                    $dates = array_fill(0, $result_imgs_count, $ts);
                    $dates = implode('***', $dates);
                    $options['nav_type'] = 'bullet' == $result['slider_nav'] ? 'dots' : $result['slider_nav'];
                    $opt = json_encode($options, TRUE);
                    $query = "INSERT INTO " . $table . " (title, description, images, images_titles, images_descs, images_alts, images_urls, width, height, options, images_dates) VALUES ('{$result['slider_name']}', '{$result['slider_caption']}', '" . rtrim($result['slider_files'], "*") . "', '" . $result['slider_text'] . "', '" . $result['slider_text'] . "', '" . $result['slider_text'] . "', '" . $result['slider_urls'] . "', '" . $result['slider_width'] . "', '" . $result['slider_height'] . "', '$opt', '" . $dates . "')";
                    $wpdb->query($query);
                }
            }
            $drop = "DROP TABLE IF EXISTS $old_table";
            $wpdb->query($drop);
        }
        $query = "SELECT * FROM $table";
        $ays_slider_infos = $wpdb->query($query);

        if (0 == $ays_slider_infos) {

            $images = array();
            $images_titles = array();
            $images_descs = array();
            $images_urls = array();
            $images_dates = array();
            for ($i = 0; $i < 11; $i++) {
                $images_descs[] = '';
                $images_urls[] = '';
                $images_dates[] = time();
            }
            $images[] = 'https://freedemo.ays-pro.com/wp-content/uploads/2018/07/photo-1497030855747-0fc424f89a4b-1350x900.jpg';
            $images[] = 'https://freedemo.ays-pro.com/wp-content/uploads/2018/07/photo-1493787039806-2edcbe808750-1350x900.jpg';
            $images[] = 'https://freedemo.ays-pro.com/wp-content/uploads/2018/07/photo-1422360902398-0a91ff2c1a1f-1316x920.jpg';
            $images[] = 'https://freedemo.ays-pro.com/wp-content/uploads/2018/07/photo-1414788101029-46aec67101ca-1353x899.jpg';
            $images[] = 'https://freedemo.ays-pro.com/wp-content/uploads/2018/07/photo-1504535497387-90c521ae8523-1327x914.jpg';
            $images[] = 'https://freedemo.ays-pro.com/wp-content/uploads/2018/07/MG_8142.jpg';
            $images[] = 'https://freedemo.ays-pro.com/wp-content/uploads/2018/07/MG_2780.jpg';
            $images[] = 'https://freedemo.ays-pro.com/wp-content/uploads/2018/07/MG_2354.jpg';
            $images[] = 'https://freedemo.ays-pro.com/wp-content/uploads/2018/07/MG_2050.jpg';
            $images[] = 'https://freedemo.ays-pro.com/wp-content/uploads/2018/07/MG_0976.jpg';
            $images[] = 'https://freedemo.ays-pro.com/wp-content/uploads/2018/04/StockSnap_ITXLIWFJTY1.jpg';
            $images_titles[] = 'Sunest in big city';
            $images_titles[] = 'Lake';
            $images_titles[] = 'City';
            $images_titles[] = 'Nature';
            $images_titles[] = 'Beautiful waterfall';
            $images_titles[] = 'Garden';
            $images_titles[] = 'Night city';
            $images_titles[] = 'Sea';
            $images_titles[] = 'Nature in mountain';
            $images_titles[] = 'Rocks';
            $images_titles[] = 'Photograph';
            $images = implode('***', $images);
            $images_titles = implode('***', $images_titles);
            $images_descs = implode('***', $images_descs);
            $images_urls = implode('***', $images_urls);
            $images_dates = implode('***', $images_dates);
            $options = array(
                "admin_pagination" => "all",
                'show_title' => 1,
                'images_orderby' => 'noordering',
                'margin' => 0,
                'images_loading' => "current_loaded",
                'nav_arrows' => 1,
                'nav_dots' => 0,
                'pause_hover' => 1,
                'animation_in' => "rubberBand",
                'animation_out' => "bounceOutDown",
                'animation_speed' => 450,
                'border_radius' => 0,
                'timeout' => 1.5,
                'image_object_fit' => 'contain',
                'slider_bgcolor' => '#ffffff',
                'slider_title_color' => '#ffffff'
            );
            $opt = json_encode($options, TRUE);
            $query = "INSERT INTO $table (title, description, images, images_titles, images_descs, images_alts, images_urls, width, height, options, images_dates) VALUES ('Default slider', 'Default slider description', '" . $images . "', '" . $images_titles . "', '" . $images_descs . "', '" . $images_titles . "', '" . $images_urls . "', '800', '600', '$opt', '" . $images_dates . "')";
            $wpdb->query($query);
        }

    }

}