<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://ays-pro.com/
 * @since      1.0.0
 *
 * @package    Ays_Slider
 * @subpackage Ays_Slider/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Ays_Slider
 * @subpackage Ays_Slider/public
 * @author     Image Slider Team <info@ays-pro.com>
 */
class Ays_Slider_Public {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $plugin_name       The name of the plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct($plugin_name, $version) {

        $this->plugin_name = $plugin_name;
        $this->version = $version;

        add_shortcode('ays_slider', array($this, 'ays_slider_generate_shortcode'));

    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_styles() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Ays_Slider_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Ays_Slider_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        wp_enqueue_style('ays_sld-animate', plugin_dir_url(__FILE__) . 'css/animate.min.css', array(), '3.7.0', 'all');
        wp_enqueue_style('ays_sld_font_awesome', plugin_dir_url(__FILE__) . 'css/font_awesome_all.css', array(), '5.6.3', 'all');
        wp_enqueue_style('ays_sld_fa_v4_shims', plugin_dir_url(__FILE__) . 'css/font_awesome_v4-shims.css', array(), '5.6.3', 'all');
        wp_enqueue_style('ays_sld-carousel', plugin_dir_url(__FILE__) . 'css/owl.carousel.min.css', array(), '2.3.4', 'all');
        wp_enqueue_style('ays_sld-carousel-theme', plugin_dir_url(__FILE__) . 'css/owl.theme.default.min.css', array(), '2.3.4', 'all');

    }

    public function enqueue_styles_early(){
        wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/ays-slider-public.css', array(), $this->version, 'all');

    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Ays_Slider_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Ays_Slider_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        wp_enqueue_script('jquery-effects-core');
        wp_enqueue_media();
        wp_enqueue_script('ays_sld_imagesloaded.min.js', plugin_dir_url(__FILE__) . 'js/imagesloaded.pkgd.min.js', array('jquery'), '4.0.0', true);
        wp_enqueue_script('ays_sld_owl.carousel.min.js', plugin_dir_url(__FILE__) . 'js/owl.carousel.min.js', array('jquery'), '2.3.4', true);
        wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/ays-slider-public.js', array('jquery'), $this->version, true);

    }

    public function ays_initialize_slider_shortcode() {
        // add_shortcode('ays_slider', array($this, 'ays_generate_slider'));
    }

    public function ays_get_slider_by_id($id) {
        global $wpdb;

        $sql = "SELECT * FROM {$wpdb->prefix}ays_slider WHERE id={$id}";

        $result = $wpdb->get_row($sql, "ARRAY_A");

        return $result;
    }

    public function ays_get_image_thumbnail($img) {
        global $wpdb;
        $this_site_path = trim(get_site_url(), "https:");
        if (strpos(trim($img, "https:"), $this_site_path) !== false) {
            $query = "SELECT * FROM {$wpdb->prefix}posts WHERE `post_type` = 'attachment' AND `guid` = '$img'";
            $result_img = $wpdb->get_results($query, "ARRAY_A");
            if (!empty($result_img)) {
              $url_img = wp_get_attachment_image_src($result_img[0]['ID'], 'thumbnail');
              if (false === $url_img) {
                  return $img;
              } else {
                  return $url_img[0];
              }
            } else {
              $url_img = $img;
              return $url_img;
            }
        } else {
            return $img;
        }

    }

    public function ays_generate_slider($attr) {
        global $wpdb;
        $id = (isset($attr['id'])) ? absint(intval($attr['id'])) : null;
        if ($id == null) {
            return "";
        }
        $slider = $this->ays_get_slider_by_id($id);
        if (empty($slider)) {
            return "";
        }
        $this->enqueue_styles();
        $this->enqueue_scripts();

        $width = $slider["width"];
        $height = $slider["height"];
        $title = $slider["title"];
        $description = $slider["description"];
        $custom_css = $slider["custom_css"];
        $sld_options = json_decode($slider['options'], true);
        $images_orderby = ('' == $sld_options['images_orderby'] || false === $sld_options['images_orderby']) ? 'noordering' : $sld_options['images_orderby'];
        $image_object_fit = (isset($sld_options['image_object_fit']) && $sld_options['image_object_fit'] != '') ? $sld_options['image_object_fit'] : 'contain';
        $slider_bgcolor = (isset($sld_options['slider_bgcolor']) && $sld_options['slider_bgcolor'] != '') ? $sld_options['slider_bgcolor'] : '#ffffff';
        $slider_title_color = (isset($sld_options['slider_title_color']) && $sld_options['slider_title_color'] != '') ? $sld_options['slider_title_color'] : '#ffffff';
        $show_title = ('' == $sld_options['show_title'] || false == $sld_options['show_title']) ? '' : $sld_options['show_title'];
        $images_distance = empty($sld_options['images_distance']) ? '20' : $sld_options['images_distance'];

        $images_loading = ('' == $sld_options['images_loading'] || false == $sld_options['images_loading']) ? 'all_loaded' : $sld_options['images_loading'];
        $b_radius = ('' == $sld_options['border_radius'] || false == $sld_options['border_radius']) ? '0' : $sld_options['border_radius'];
        /*
         * Gallery image settings
         */
//        var_dump($sld_options);
        $images = explode("***", $slider["images"]);
        $image_titles = explode("***", $slider["images_titles"]);
        $image_descs = explode("***", $slider["images_descs"]);
        $image_alts = explode("***", $slider["images_alts"]);
        $image_urls = explode("***", $slider["images_urls"]);

        if ('' == $slider["images_dates"] || null == $slider["images_dates"]) {
            $image_dates = array();
            for ($i = 0; $i < count($images); $i++) {
                $image_dates[] = time();
            }
        } else {
            $image_dates = explode("***", $slider["images_dates"]);
        }

        if ('' == $image_dates) {
            $image_dates = array();
            for ($i = 0; $i < count($images); $i++) {
                $image_dates[] = time();
            }
        }
        switch ($images_orderby) {
        case 'title':
            array_multisort($image_titles, SORT_ASC, SORT_STRING, $images, $image_descs, $image_alts, $image_urls, $image_dates);
            break;
        case 'date':
            array_multisort($image_dates, SORT_ASC, SORT_NUMERIC, $images, $image_titles, $image_descs, $image_alts, $image_urls);
            break;
        case 'random':
            $images_indexes = range(0, count($images) - 1);
            shuffle($images_indexes);
            array_multisort($images_indexes, $images, $image_titles, $image_descs, $image_alts, $image_urls, $image_dates);
            break;
        }

        $images_count = count($images);

        $img_thumbs = array();
        foreach ($images as $path) {
            $img_thumbs[] = $this->ays_get_image_thumbnail($path);
        }
        $ays_width = 0 == $width ? '100%' : $width . 'px';
        $ays_height = 0 == $height ? '600px' : $height . 'px';
        $ays_slider_id = uniqid('ays-slider-');

        $lazyload = $sld_options['images_loading'] == 'current_loaded' ? 'true' : 'false';
        $titles = isset($sld_options['show_title']) && $sld_options['show_title'] == 1 ? 'block' : 'none';
        $pause = isset($sld_options['pause_hover']) && $sld_options['pause_hover'] == 1 ? 'true' : 'false';
        $arrows = isset($sld_options['nav_arrows']) && $sld_options['nav_arrows'] == 1 ? 'true' : 'false';
        $dots = isset($sld_options['nav_type']) && $sld_options['nav_type'] == 'dots' ? 'true' : 'false';
        $thumbs = (isset($sld_options['nav_type']) && $sld_options['nav_type'] == 'thumb');
        $thumb_h = (isset($sld_options['thumb_h']) ? intval($sld_options['thumb_h']) : 50);
        $thumb_w = (isset($sld_options['thumb_w']) ? intval($sld_options['thumb_w']) : 50);
        $thumb_c = (isset($sld_options['thumb_c']) ? intval($sld_options['thumb_c']) : 3);
        $animate_in = isset($sld_options['animation_in']) && !empty($sld_options['animation_in']) ? $sld_options['animation_in'] : '';
        $animate_out = isset($sld_options['animation_out']) && !empty($sld_options['animation_out']) ? $sld_options['animation_out'] : '';
        $smart_speed = isset($sld_options['animation_speed']) && !empty($sld_options['animation_speed']) ? $sld_options['animation_speed'] : 400;
        $margin = isset($sld_options['margin']) && !empty($sld_options['margin']) ? $sld_options['margin'] : 0;
        $border_radius = isset($sld_options['border_radius']) && !empty($sld_options['border_radius']) ? $sld_options['border_radius'] : 0;
        $timeout = isset($sld_options['timeout']) && !empty($sld_options['timeout']) ? $sld_options['timeout'] : 3000;
        $timeout = $timeout < 500 ? 3000 : $timeout;
        $filter = (isset($sld_options['filter'])) ? $sld_options['filter'] : 'none';
        $filter_value = (isset($sld_options['filter_value']) && $sld_options['filter'] != 'none' && $sld_options['filter_value'] != '') ? $sld_options['filter_value'] : '';
        switch ($filter) {
        case 'blur':
            $cssFilter = "$filter({$filter_value}px)";
            break;
        case 'hue-rotate':
            $cssFilter = "$filter({$filter_value}deg)";
            break;
        case 'none':
            $cssFilter = "none";
            break;
        default:
            $cssFilter = "$filter($filter_value)";
            break;
        }

        $content = "<style>
      #$ays_slider_id {
        width: $ays_width;
        height: $ays_height;
                max-width: 100%;
                border-radius: {$border_radius}px;
                margin: 1rem auto;
                overflow: hidden;
      }
      #$ays_slider_id .owl-carousel {
        height: 100%;
      }     

      #$ays_slider_id .ays-img-container>img {
                height: $ays_height;
                border-radius: {$border_radius}px;
                -webkit-filter: $cssFilter;
                filter: $cssFilter;
                object-fit: ".$image_object_fit.";
            }
            #$ays_slider_id .ays-slider-img-title {
                position: absolute;
                width: 100%;
                top: 0;
                text-align:center;
                display: $titles;
                text-shadow: 0 -1px 0 rgba(48, 52, 63, 1), 0 1px 0 rgba(48, 52, 63, 1), -1px 0 0 rgba(48, 52, 63, 1), 1px 0 0 rgba(48, 52, 63, 1), 1px -1px 0 rgba(48, 52, 63, 1), -1px 1px 0 rgba(48, 52, 63, 1), -1px -1px 0 rgba(48, 52, 63, 1), 1px 1px 0 rgba(48, 52, 63, 1) !important;
                color: whitesmoke;
                z-index: 20;
                text-decoration: none;
                box-shadow: none;
                background-color: ".$slider_title_color.";
            }
            #$ays_slider_id .owl-dots:not(#carousel-custom-dots-$ays_slider_id) {
                top: " . ('true' == $arrows ? "-25%" : "-12%") . ";
            }
            div.carousel-custom-dots-$ays_slider_id {
                position: relative;
                width: " . $thumb_w * $thumb_c ."px;
                top: " . (-$thumb_h - 16) . "px;
                z-index: 100;
                transition: 0.2s ease-in-out;
                margin: 0 auto !important;
                max-width: 100%;
                overflow:hidden;
            }
            div#carousel-custom-dots-$ays_slider_id .owl-item {
                width: ".$thumb_w."px;
                height: ".$thumb_h."px;
            }
            div#carousel-custom-dots-$ays_slider_id div.owl-item img {
                min-width: ".$thumb_w."px;
                height: ".$thumb_h."px;
            }

            #$ays_slider_id .owl-item{
              background-color: ".$slider_bgcolor.";
            }
        </style>";

        $thumbs_script = "";
        if($thumbs){
          $thumbs_script = "
              var thumbs = $('#carousel-custom-dots-$ays_slider_id');
              var syncedSecondary = true;
              owl.on('changed.owl.carousel', syncPosition);
              thumbs.on('initialized.owl.carousel', function () {
                  thumbs.find('.owl-item').eq(0).addClass('current');
              }).owlCarousel({
                center:true,
                items: $thumb_c,
                dots: false,
                nav: false,
                smartSpeed: 200,
                slideSpeed: 500,
                slideBy: $thumb_c,
                responsiveRefreshRate : 100
              }).on('changed.owl.carousel', syncPosition2);

              function syncPosition(el) {
                  var count = el.item.count-1;
                  var current = Math.round(el.item.index - (el.item.count/2) - 0.5);

                  if(current < 0) {
                    current = count;
                  }
                  if(current > count) {
                    current = 0;
                  }

                  thumbs.find('.owl-item').removeClass('current').eq(current).addClass('current');
                  var onscreen = thumbs.find('.owl-item.active').length - 1;
                  var start = thumbs.find('.owl-item.active').first().index();
                  var end = thumbs.find('.owl-item.active').last().index();

                  if (current > end) {
                    thumbs.data('owl.carousel').to(current, 100, true);
                  }
                  if (current < start) {
                    thumbs.data('owl.carousel').to(current - onscreen, 100, true);
                  }
              }

              function syncPosition2(el) {
                if(syncedSecondary) {
                  var number = el.item.index;
                  owl.data('owl.carousel').to(number, 100, true);
                }
              }
              thumbs.on('click', '.owl-item', function(e){
                e.preventDefault();
                var number = $(this).index();
                owl.data('owl.carousel').to(number, 300, true);
              }); ";
        }

        $content .= "
        <script>
        (function($) {
            $(document).ready(function(){
                let owl = $('#$ays_slider_id .owl-carousel');
                owl.owlCarousel({
                    animateOut: '$animate_out',
                    animateIn: '$animate_in',
                    stagePadding: 0,
                    smartSpeed: $smart_speed,
                    items: 1,
                    loop: true,
                    margin: $margin,
                    autoplay: true,
                    autoplayTimeout: $timeout,
                    slideSpeed: $timeout,
                    autoplayHoverPause: $pause,
                    nav: $arrows,
                    dots: $dots,
                    lazyLoad: $lazyload
                }); 
                owl.on('changed.owl.carousel', function() {
                    owl.trigger('stop.owl.autoplay');
                    owl.trigger('play.owl.autoplay');
                });
                ";

        $content .= $thumbs_script;

        $content .= "
            });
        })(jQuery);
        </script><style>{$slider['custom_css']}</style>";
        $content .= "<div class='ays-slider-container' id='$ays_slider_id'>";
        $content .= "<div class='owl-carousel owl-theme'>";
        foreach ($images as $key => $img) {
            $content .= "<div class='ays-img-container item'>";
            if (isset($image_urls[$key]) && !empty($image_urls[$key])) {
                $content .= "<a href='{$image_urls[$key]}' class='ays-slider-img-title'>{$image_titles[$key]}</a>";
            } else {
                $content .= "<span class='ays-slider-img-title'>{$image_titles[$key]}</span>";
            }
            $content .= "<img " . ('current_loaded' == $sld_options['images_loading'] ? "data-src='$img' class='owl-lazy'" : "") . "src='$img' title='{$image_titles[$key]}' alt='{$image_alts[$key]}'>
      </div>";
        }

        $content .= "</div></div><div class='carousel-custom-dots-$ays_slider_id'>";
        if ($thumbs) {
            $content .= "<div id='carousel-custom-dots-$ays_slider_id' class='owl-carousel owl-theme'>";
            foreach ($img_thumbs as $img) {
                $content .= "<div class='item'>
                    <img src='$img'>
                </div>";
            }
            $content .= "</div></div>";
        } else {
            $content .= "</div>";
        }

        echo $content;
    }
    public function ays_slider_generate_shortcode($attr) {
        ob_start();

        $this->ays_generate_slider($attr);

        return str_replace(array("\r\n", "\n", "\r"), '', ob_get_clean());
    }
}